@@ -2,19 +2,20 @@
  * Copyright (c) 1997, 1998, 1999, 2000, 2002, 2003, 2004, 2006
  *	Tama Communications Corporation
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ * This file is part of GNU GLOBAL.
  *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -313,7 +314,8 @@ main(int argc, char **argv)
 void
 getdefinitionURL(const char *arg, STRBUF *URL)
 {
-	char *path, *p;
+	const char *path;
+	char *p;
 	STRBUF *sb = NULL;
 	DBOP *dbop = NULL;
 	SPLIT ptable;
